@@ -106,7 +106,7 @@ QString dateTimeToString(uint date)
         return QString();
     }
 
-    const QString format = QLatin1String("ddd MMM d HH:mm:ss yyyy");
+    const QString format = QStringLiteral("ddd MMM d HH:mm:ss yyyy");
     QDateTime dt;
     dt.setTime_t(date);
     return dt.toUTC().toString(format);
@@ -157,21 +157,21 @@ QString htmlToPlainText(const QString &html)
 {
     QString str(html);
     //TODO: preserve some formatting, such as line breaks
-    str.remove(QRegExp(QLatin1String("<[^>]*>"))); // remove tags
+    str.remove(QRegExp(QStringLiteral("<[^>]*>"))); // remove tags
     str = resolveEntities(str);
     return str.trimmed();
 }
 
-namespace
+static QRegExp tagRegExp()
 {
-static QRegExp tagRegExp;
-static bool tagRegExpSet = false;
+    static QRegExp exp(QStringLiteral("<\\w+.*/?>"));
+    return exp;
 }
 
 bool stringContainsMarkup(const QString &str)
 {
     //check for entities
-    if (str.contains(QRegExp(QLatin1String("&[a-zA-Z0-9#]+;")))) {
+    if (str.contains(QRegExp(QStringLiteral("&[a-zA-Z0-9#]+;")))) {
         return true;
     }
 
@@ -180,17 +180,13 @@ bool stringContainsMarkup(const QString &str)
         return false;
     }
 
-    if (!tagRegExpSet) {
-        tagRegExp = QRegExp(QLatin1String("<\\w+.*/?>"));
-        tagRegExpSet = true;
-    }
-    return str.contains(tagRegExp);
+    return str.contains(tagRegExp());
 }
 
 bool isHtml(const QString &str)
 {
     //check for entities
-    if (str.contains(QRegExp(QLatin1String("&[a-zA-Z0-9#]+;")))) {
+    if (str.contains(QRegExp(QStringLiteral("&[a-zA-Z0-9#]+;")))) {
         return true;
     }
 
@@ -199,15 +195,7 @@ bool isHtml(const QString &str)
         return false;
     }
 
-    if (!tagRegExpSet) {
-        tagRegExp = QRegExp(QLatin1String("<\\w+.*/?>"));
-        tagRegExpSet = true;
-    }
-    if (str.contains(tagRegExp)) {
-        return true;
-    }
-
-    return false;
+    return str.contains(tagRegExp());
 }
 
 QString normalize(const QString &str)
@@ -249,7 +237,7 @@ PersonPtr personFromString(const QString &strp)
     // look for something looking like a mail address ("foo@bar.com",
     // "<foo@bar.com>") and extract it
 
-    QRegExp remail(QLatin1String("<?([^@\\s<]+@[^>\\s]+)>?")); // FIXME: user "proper" regexp,
+    QRegExp remail(QStringLiteral("<?([^@\\s<]+@[^>\\s]+)>?")); // FIXME: user "proper" regexp,
     // search kmail source for it
 
     int pos = remail.indexIn(str);
@@ -260,8 +248,8 @@ PersonPtr personFromString(const QString &strp)
     }
 
     // replace "mailto", "(", ")" (to be extended)
-    email.remove(QLatin1String("mailto:"));
-    email.remove(QRegExp(QLatin1String("[\\(\\)]")));
+    email.remove(QStringLiteral("mailto:"));
+    email.remove(QRegExp(QStringLiteral("[\\(\\)]")));
 
     // simplify the rest and use it as name
 
@@ -273,7 +261,7 @@ PersonPtr personFromString(const QString &strp)
     // str is of the format "Foo M. Bar (President)",
     // we should not cut anything.
 
-    QRegExp rename(QLatin1String("^\\(([^\\)]*)\\)"));
+    QRegExp rename(QStringLiteral("^\\(([^\\)]*)\\)"));
 
     if (rename.exactMatch(name)) {
         name = rename.cap(1);
